==> filemv0.41.zip: source/dir.cpp <==
#include "defextern.h"

#include "myfilemv.h"
#include "initial.h"

BOOL isclip(char *d)
{
	return (strncmp(_CLIP, d, _ClipLen)==0) ;
}

BOOL dirw::isclip()
{
	return ::isclip(dir);
}


char clipdirfile[MAX_PATH];
#define keydir "dir"
#define keydirnum "num"

// clip:abc  >> abc.ini ɐݒ

void initclip(char *dir)
{
	wsprintf(clipdirfile,"%s\\%s.ini",getCdir(), dir+5);
}

// clipǉ
//
// clip
//   [num]
//   num=1
//   [dir]
//   1=c:\... etc.

BOOL addclip(char *from, char *to)
{
	if(strlen(to)<=_ClipLen) return FALSE;
	initclip(to);
	int num =GetPrivateProfileInt(keydirnum, keydirnum, 0, clipdirfile);

	num++;
	char buf[10];
	wsprintf(buf, "%d", num);
	WritePrivateProfileString(keydir, buf, from, clipdirfile);
	WritePrivateProfileString(keydirnum, keydirnum, buf, clipdirfile);
	return TRUE;
}


void openClip(char *dir)
{
	initclip(dir);
	//GetPrivateProfileString(keydir, "", "", buffer, MAX_PATH, clipdirfile);

	return;
}

void Exchange(dirw &ldir, dirw &rdir)
{
	/*
	char buf[1000];
	ldir.GetCurrentDirectory(1000,buf);
	ldir.SetCurrentDirectory(rdir.cd());
	rdir.SetCurrentDirectory(buf);
	*/
	HWND ledit=ldir.getEdit();
	HWND llist=ldir.getList();
	HWND redit=rdir.getEdit();
	HWND rlist=rdir.getList();
	dirw dir=ldir;

	ldir =rdir;
	rdir =dir;

	ldir.setList(llist);
	rdir.setList(rlist);
	ldir.setEdit(ledit);
	rdir.setEdit(redit);
}

void dirw::savedir()
{
	savehisdir(tab, dir);
};

void dirw::savedir(char* path)
{
	savehisdir(tab, path);
};


int dirw::getClipMax()
{
	clipmax =GetPrivateProfileInt(keydirnum, keydirnum, 0, clipdirfile);
	return clipmax;
}

char *dirw::getClip(int num)
{
	static char buf[10], ans[MAX_PATH];
	wsprintf(buf, "%d", num);
	GetPrivateProfileString(keydir, buf, "", ans, MAX_PATH, clipdirfile);
	return ans;
}

char *dirw::SetCurrentDirectory(char *d)
{
	//
	BOOL f=FALSE;
	if( isclip() && d==".") return dir;
	if( ::isclip(d) ) 
	{
		wsprintf(dir, d);
		space=0;
		total=0;
		openClip(dir);
		return dir;
	}

	if(strcmp(dir,d)==0 && strlen(d)>0) f=TRUE;
	::SetCurrentDirectory(dir);
	::SetCurrentDirectory(d);
	::GetCurrentDirectory(1000,dir);
	//Mes(dir);
	setDirHis(dir);
	wsprintf(drive,"%s",dir);
	if(!f && strlen(d)>0) savedir();
	char *p =strchr( drive,'\\' );
	if (p !=NULL ) if(strlen(p) >1 ) p[1]=0;
	int i=GetDiskFreeSpaceEx( drive, &FreeBytesAv,
		&Bytes,
		&FreeBytes);
//	(double)FreeAvBytes.u.HighPart*4294967296.0 + (double)FreeAvBytes.u.LowPart
	if(i) 
	{
		space =((double)(FreeBytesAv.u.LowPart)+
			(double)FreeBytesAv.u.HighPart*4294967296.0)/1024/1024;
		total =((double)(Bytes.u.LowPart)+
			(double)Bytes.u.HighPart*4294967296.0)/1024/1024;
	}
	//space =(double)NumberOfFreeClusters *SectorsPerCluster *BytesPerSector/1024/1024;
	else {space =0;total =0;};
	return dir;
};

void dirw::hisback()
{
	hispos(-1);
	setDir(dirhis);
	cd(dir);
};

void dirw::hisnext()
{
	hispos(1);
	setDir(dirhis);
	cd(dir);
};
// reloadȂ

void dirw::hisBackSee()
{
	hispos(-1);
};

void dirw::hisNextSee()
{
	hispos(1);
};

void dirw::hispos(int i)
{
	loadhisdir(tab, dirhis, i);
	//setDir(dirhis);
}

==> filemv0.47.zip: source/dir.cpp <==
#include "defextern.h"

#include "myfilemv.h"
#include "initial.h"
#include "tab.h"

BOOL isclip(char *d)
{
	return (strncmp(_CLIP, d, strlen(_CLIP))==0);
}

BOOL ishis(char *d)
{
	return (strncmp(_HIS, d, strlen(_HIS))==0);
}

BOOL dirw::isclip()
{
	clipf =::isclip(dir);
	return clipf;
}

BOOL dirw::ishis()
{
	hisf =::ishis(dir);
	if(strlen(dir)<5 || dir[4]=='R' || dir[4]=='r') hisRf =TRUE;
	else hisLf =TRUE;
	return hisf;
}


char clipdirfile[MAX_PATH];
#define keydir "dir"
#define keydirnum "num"

// clip:abc  >> abc.ini ɐݒ

void initclip(char *dir)
{
	wsprintf(clipdirfile,"%s\\%s.ini",getCdir(), dir+5);
}

// clipǉ
//
// clip
//   [num]
//   num=1
//   [dir]
//   1=c:\... etc.

BOOL addclip(char *from, char *to)
{
	if(strlen(to)<=_ClipLen) return FALSE;
	initclip(to);
	int num =GetPrivateProfileInt(keydirnum, keydirnum, 0, clipdirfile);

	num++;
	char buf[10];
	wsprintf(buf, "%d", num);
	WritePrivateProfileString(keydir, buf, from, clipdirfile);
	WritePrivateProfileString(keydirnum, keydirnum, buf, clipdirfile);
	return TRUE;
}


void openClip(char *dir)
{
	initclip(dir);
	//GetPrivateProfileString(keydir, "", "", buffer, MAX_PATH, clipdirfile);

	return;
}

void Exchange(dirw &ldir, dirw &rdir)
{
	/*
	char buf[1000];
	ldir.GetCurrentDirectory(1000,buf);
	ldir.SetCurrentDirectory(rdir.cd());
	rdir.SetCurrentDirectory(buf);
	*/
	HWND ledit=ldir.getEdit();
	HWND llist=ldir.getList();
	HWND redit=rdir.getEdit();
	HWND rlist=rdir.getList();
	dirw dir=ldir;

	ldir =rdir;
	rdir =dir;

	ldir.setList(llist);
	rdir.setList(rlist);
	ldir.setEdit(ledit);
	rdir.setEdit(redit);
}

void dirw::savedir()
{
	savehisdir(tab, dir);
};

void dirw::savedir(char* path)
{
	savehisdir(tab, path);
};


int dirw::getClipMax()
{
	if( !hisf) clipmax =GetPrivateProfileInt(keydirnum, keydirnum, 0, clipdirfile);
	else 
	{
		if(hisLf) clipmax =gethismax(tab_l);
		else clipmax =gethismax(tab_r);
	}
	return clipmax;
}

void getclipstr(char *key, char *ti, char *ans, char *file)
{
	GetPrivateProfileString(key, ti, "", ans, MAX_PATH, file);
}


extern char hisldirfile[];
extern char hisrdirfile[];
extern char keyhis[];

char *dirw::getClip(int num)
{
	static char buf[10], ans[MAX_PATH];
	wsprintf(buf, "%d", num);
	if(!hisf) getclipstr(keydir, buf, ans, clipdirfile);
	if(hisRf) getclipstr(keyhis, buf, ans, hisrdirfile);
	if(hisLf) getclipstr(keyhis, buf, ans, hisldirfile);
	return ans;
}

char *dirw::SetCurrentDirectory(char *d)
{
	//
	BOOL f=FALSE;
	if( (isclip() || ishis() ) && d==".") return dir;
	if(strcmp(dir,d)==0 && strlen(d)>0) f=TRUE;
	if( ::isclip(d) ) 
	{
		wsprintf(dir, d);
		space=0;
		total=0;
		openClip(dir);
		savedir();
		return dir;
	}
	if( ::ishis(d) ) 
	{
		hisf =TRUE;
		if(strncmp("his:R",d,5)==0 || strncmp("his:r",d,5)==0) 
		{
			hisRf =TRUE;
			wsprintf(dir, "his:R");
		}
		else 
		{
			hisLf =TRUE;
			wsprintf(dir, "his:L");
		}
		space=0;
		total=0;
		savedir();
		return dir;
	}

	::SetCurrentDirectory(dir);
	::SetCurrentDirectory(d);
	::GetCurrentDirectory(1000,dir);
	//Mes(dir);
	setDirHis(dir);
	wsprintf(drive,"%s",dir);
	if(!f && strlen(d)>0) savedir();
	char *p =strchr( drive,'\\' );
	if (p !=NULL ) if(strlen(p) >1 ) p[1]=0;
	int i=GetDiskFreeSpaceEx( drive, &FreeBytesAv,
		&Bytes,
		&FreeBytes);
//	(double)FreeAvBytes.u.HighPart*4294967296.0 + (double)FreeAvBytes.u.LowPart
	if(i) 
	{
		space =((double)(FreeBytesAv.u.LowPart)+
			(double)FreeBytesAv.u.HighPart*4294967296.0)/1024/1024;
		total =((double)(Bytes.u.LowPart)+
			(double)Bytes.u.HighPart*4294967296.0)/1024/1024;
	}
	//space =(double)NumberOfFreeClusters *SectorsPerCluster *BytesPerSector/1024/1024;
	else {space =0;total =0;};
	return dir;
};

void dirw::hisback()
{
	hispos(-1);
	setDir(dirhis);
	cd(dir);
};

void dirw::hisnext()
{
	hispos(1);
	setDir(dirhis);
	cd(dir);
};
// reloadȂ

void dirw::hisBackSee()
{
	hispos(-1);
};

void dirw::hisNextSee()
{
	hispos(1);
};

void dirw::hispos(int i)
{
	loadhisdir(tab, dirhis, i);
	//setDir(dirhis);
}
